@@ -6,7 +6,6 @@ import time
 import torch
 from torch.utils.data import DataLoader
 import numpy as np
-import gc
 import operator
 
 from lightwood.mixers.helpers.default_net import DefaultNet
@@ -33,11 +32,11 @@ class NnMixer:
         self.encoders = None
         self.optimizer_class = None
         self.optimizer_args = None
+        self.selfaware_optimizer_args = None
         self.criterion_arr = None
         self.unreduced_criterion_arr = None
 
         self.batch_size = 200
-        self.epochs = 120000
 
         self.nn_class = DefaultNet
         self.dynamic_parameters = dynamic_parameters
@@ -251,6 +250,7 @@ class NnMixer:
                                 self.adjust(test_ds)
                             else:
                                 self.update_model(best_model)
+                            self.iter_fit(test_ds, initialize=first_run, max_epochs=1)
                             self.encoders = train_ds.encoders
                             logging.info('Finished training model !')
                             break
@@ -509,7 +509,7 @@ class NnMixer:
         self.encoders = ds.encoders
         self.transformer = ds.transformer
 
-    def iter_fit(self, ds, initialize=True, subset_id=None):
+    def iter_fit(self, ds, initialize=True, subset_id=None, max_epochs=120000):
         """
         :param ds:
         :return:
@@ -581,34 +581,27 @@ class NnMixer:
 
             self.optimizer = self.optimizer_class(self.net.parameters(), **self.optimizer_args)
 
-            self.optimizer_args['lr'] = self.optimizer.lr * self.selfaware_lr_factor
+            self.selfaware_optimizer_args = copy.deepcopy(self.optimizer_args)
+            self.selfaware_optimizer_args['lr'] = self.selfaware_optimizer_args['lr'] * self.selfaware_lr_factor
             self.selfaware_optimizer = self.optimizer_class(self.selfaware_net.parameters(), **self.optimizer_args)
 
-        total_epochs = self.epochs
-
         if self._nonpersistent['sampler'] is None:
             data_loader = DataLoader(ds, batch_size=self.batch_size, shuffle=True, num_workers=0)
         else:
             data_loader = DataLoader(ds, batch_size=self.batch_size, num_workers=0,
                                      sampler=self._nonpersistent['sampler'])
 
-        for epoch in range(total_epochs):  # loop over the dataset multiple times
+        for epoch in range(max_epochs):  # loop over the dataset multiple times
             running_loss = 0.0
             error = 0
             for i, data in enumerate(data_loader, 0):
                 if self.start_selfaware_training and not self.is_selfaware:
-                    logging.info('Making network selfaware !')
+                    logging.info('Starting to train selfaware network for better confidence determination !')
                     self.is_selfaware = True
-                    gc.collect()
-                    if 'cuda' in str(self.net.device):
-                        torch.cuda.empty_cache()
 
                 if self.stop_selfaware_training and self.is_selfaware:
-                    logging.info('Cannot train selfaware network, training a normal network instead !')
+                    logging.info('Cannot train selfaware network, will fallback to using simpler confidence models !')
                     self.is_selfaware = False
-                    gc.collect()
-                    if 'cuda' in str(self.net.device):
-                        torch.cuda.empty_cache()
 
                 self.total_iterations += 1
                 # get the inputs; data is a list of [inputs, labels]
@@ -712,52 +705,3 @@ class NnMixer:
         self.net.to(device, available_devices)
         self.selfaware_net.to(device, available_devices)
         return self
-
-if __name__ == "__main__":
-    import random
-    import pandas
-    from lightwood.api.data_source import DataSource
-    from lightwood.data_schemas.predictor_config import predictor_config_schema
-
-    config = {
-        'input_features': [
-            {
-                'name': 'x',
-                'type': 'numeric'
-            },
-            {
-                'name': 'y',
-                'type': 'numeric'
-            }
-        ],
-
-        'output_features': [
-            {
-                'name': 'z',
-                'type': 'numeric'
-            },
-            {
-                'name': 'z`',
-                'type': 'categorical'
-            }
-        ]
-    }
-    config = predictor_config_schema.validate(config)
-
-    data = {'x': [i for i in range(10)], 'y': [random.randint(i, i + 20) for i in range(10)]}
-    nums = [data['x'][i] * data['y'][i] for i in range(10)]
-
-    data['z'] = [i + 0.5 for i in range(10)]
-    data['z`'] = ['low' if i < 50 else 'high' for i in nums]
-
-    data_frame = pandas.DataFrame(data)
-    ds = DataSource(data_frame, config)
-    ds.prepare_encoders()
-
-    mixer = NnMixer({}, config)
-    mixer.fit(ds,ds, stop_training_after_seconds=50)
-
-    predict_input_ds = DataSource(data_frame[['x', 'y']], config)
-    predict_input_ds.prepare_encoders()
-    predictions = mixer.predict(predict_input_ds)
-    print(predictions)
